@@ -28,7 +28,7 @@ issue_attention_diversity <- function(data,
                                                                   c(607, 608),
                                                                   c(701, 702))) {
   
-  methods <- list(shannon = function(x) { x %>% mutate_all(funs(. * log_0(.))) %>% rowSums() %>% { exp(-.)} },
+  methods <- list(shannon = function(x) { x %>% mutate_all(~{ . * log_0(.)}) %>% rowSums() %>% { exp(-.)} },
                   herfindahl = function(x) { 1/rowSums(x*x) })
   
   prefix_cat <- function(cat) { paste0(prefix, cat)}
