@@ -31,9 +31,11 @@
 #' @importFrom utils head tail
 #' @import zoo
 #' @importFrom psych fa
+#' @importFrom purrr map map_if map_at map_chr map_dbl map_chr map_df map_dfc map_lgl map_int walk
 #' @import NLP
 #' @import tibble
 #' @import dplyr
+#' @import tidyselect
 #' @import functional
 #' @import tm
 #' @import jsonlite
@@ -41,12 +43,13 @@ NULL
 
 ## A fix to let CRAN check NOTEs diasappear for non-standard-evaluation used
 ## cf. http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(c("one_of", ".", "matches", "starts_with", "contains", # dplyr
+globalVariables(c("one_of", "all_of", ".", "matches", "starts_with", "contains", # dplyr
                   "manifesto_id", "country", "party", "edate", "per0", # general dataset
                   "md5sum_text.x", "md5sum_text.y", "code", "manifestos", # & metadata & api download
                   "download", "url_original", "is_primary_doc", "originals", "annotations",
                   "name", "tag", # metadata versions
                   "the_score", "leadedate", "leglength", "countryname", "w", "p", # scaling
+                  "cols", "col_integer", "col_character", "col_date", "col_double", # readr
                   "p_lead", "p_lag", "lrcorescores", # median_voter_single
                   "position", "voteshare", "cumvoteshare",
                   "above50", "contains_median", "leftbound", "rightbound",
